@@ -327,6 +327,26 @@ GType xfdashboard_theme_effects_error_enum_get_type(void)
 /* enumerations from "theme-layout.h" */
 #include "theme-layout.h"
 
+GType xfdashboard_theme_layout_build_get_get_type(void)
+{
+	static volatile gsize	g_define_type_id__volatile=0;
+
+	if(g_once_init_enter(&g_define_type_id__volatile))
+	{
+		static const GEnumValue values[]=
+		{
+			{ XFDASHBOARD_THEME_LAYOUT_BUILD_GET_FOCUSABLES, "XFDASHBOARD_THEME_LAYOUT_BUILD_GET_FOCUSABLES", "focusables" },
+			{ XFDASHBOARD_THEME_LAYOUT_BUILD_GET_SELECTED_FOCUS, "XFDASHBOARD_THEME_LAYOUT_BUILD_GET_SELECTED_FOCUS", "selected-focus" },
+			{ 0, NULL, NULL }
+		};
+
+		GType	g_define_type_id=g_enum_register_static(g_intern_static_string("XfdashboardThemeLayoutBuildGet"), values);
+		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
+	}
+
+	return(g_define_type_id__volatile);
+}
+
 GType xfdashboard_theme_layout_error_enum_get_type(void)
 {
 	static volatile gsize	g_define_type_id__volatile=0;
@@ -570,5 +590,54 @@ GType xfdashboard_view_fit_mode_get_type(void)
 }
 
 
+/* enumerations from "window-tracker-window.h" */
+#include "window-tracker-window.h"
+
+GType xfdashboard_window_tracker_window_state_get_type(void)
+{
+	static volatile gsize	g_define_type_id__volatile=0;
+
+	if(g_once_init_enter(&g_define_type_id__volatile))
+	{
+		static const GFlagsValue values[]=
+		{
+			{ XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_HIDDEN, "XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_HIDDEN", "hidden" },
+			{ XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_MINIMIZED, "XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_MINIMIZED", "minimized" },
+			{ XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_MAXIMIZED, "XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_MAXIMIZED", "maximized" },
+			{ XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_FULLSCREEN, "XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_FULLSCREEN", "fullscreen" },
+			{ XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_SKIP_PAGER, "XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_SKIP_PAGER", "skip-pager" },
+			{ XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_SKIP_TASKLIST, "XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_SKIP_TASKLIST", "skip-tasklist" },
+			{ XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_PINNED, "XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_PINNED", "pinned" },
+			{ XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_URGENT, "XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_URGENT", "urgent" },
+			{ 0, NULL, NULL }
+		};
+
+		GType	g_define_type_id=g_flags_register_static(g_intern_static_string("XfdashboardWindowTrackerWindowState"), values);
+		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
+	}
+
+	return(g_define_type_id__volatile);
+}
+
+GType xfdashboard_window_tracker_window_action_get_type(void)
+{
+	static volatile gsize	g_define_type_id__volatile=0;
+
+	if(g_once_init_enter(&g_define_type_id__volatile))
+	{
+		static const GFlagsValue values[]=
+		{
+			{ XFDASHBOARD_WINDOW_TRACKER_WINDOW_ACTION_CLOSE, "XFDASHBOARD_WINDOW_TRACKER_WINDOW_ACTION_CLOSE", "close" },
+			{ 0, NULL, NULL }
+		};
+
+		GType	g_define_type_id=g_flags_register_static(g_intern_static_string("XfdashboardWindowTrackerWindowAction"), values);
+		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
+	}
+
+	return(g_define_type_id__volatile);
+}
+
+
 /* Generated data ends here */
 
