@@ -35,6 +35,7 @@
 #include <libxfdashboard/bindings-pool.h>
 #include <libxfdashboard/application.h>
 #include <libxfdashboard/compat.h>
+#include <libxfdashboard/debug.h>
 
 
 /* Define this class in GObject system */
@@ -62,6 +63,8 @@ enum
 	SIGNAL_CHANGED,
 
 	/* Actions */
+	ACTION_FOCUS_MOVE_FIRST,
+	ACTION_FOCUS_MOVE_LAST,
 	ACTION_FOCUS_MOVE_NEXT,
 	ACTION_FOCUS_MOVE_PREVIOUS,
 
@@ -174,13 +177,110 @@ static GSList* _xfdashboard_focus_manager_get_targets_for_binding(XfdashboardFoc
 	}
 
 	/* Return list of targets found */
-	g_debug("Target list for action '%s' and target class '%s' has %d entries",
-				xfdashboard_binding_get_action(inBinding),
-				xfdashboard_binding_get_target(inBinding),
-				g_slist_length(targets));
+	XFDASHBOARD_DEBUG(self, MISC,
+						"Target list for action '%s' and target class '%s' has %d entries",
+						xfdashboard_binding_get_action(inBinding),
+						xfdashboard_binding_get_target(inBinding),
+						g_slist_length(targets));
 	return(targets);
 }
 
+/* Action signal to move focus to first focusable actor was emitted */
+static gboolean _xfdashboard_focus_manager_move_focus_first(XfdashboardFocusManager *self,
+															XfdashboardFocusable *inSource,
+															const gchar *inAction,
+															ClutterEvent *inEvent)
+{
+	XfdashboardFocusManagerPrivate	*priv;
+	XfdashboardFocusable			*currentFocusable;
+	XfdashboardFocusable			*newFocusable;
+	GList							*iter;
+
+	g_return_val_if_fail(XFDASHBOARD_IS_FOCUS_MANAGER(self), CLUTTER_EVENT_PROPAGATE);
+	g_return_val_if_fail(inEvent, CLUTTER_EVENT_PROPAGATE);
+
+	priv=self->priv;
+
+	/* Get current focus */
+	currentFocusable=xfdashboard_focus_manager_get_focus(self);
+
+	/* Iterate through registered focusable actor and find the first focusable one.
+	 * We do not use xfdashboard_focus_manager_get_next_focusable(self, NULL) as
+	 * it could return a focusable actor which is beyond the current one in order.
+	 * We do not want to change the focus if it is not "before" the current one.
+	 */
+	for(iter=priv->registeredFocusables; iter; iter=g_list_next(iter))
+	{
+		newFocusable=(XfdashboardFocusable*)iter->data;
+
+		/* If iterate reached the current focused actor then there it is no first
+		 * focusable actor and we do not need to change the focus and can return.
+		 */
+		if(currentFocusable && newFocusable==currentFocusable) return(CLUTTER_EVENT_STOP);
+
+		/* If focusable can be focused then focus it and return */
+		if(xfdashboard_focusable_can_focus(newFocusable))
+		{
+			xfdashboard_focus_manager_set_focus(self, newFocusable);
+
+			return(CLUTTER_EVENT_STOP);
+		}
+	}
+
+	/* If we get here we iterated through all registered focusable actors but
+	 * could not find a matching one to set focus to.
+	 */
+	return(CLUTTER_EVENT_STOP);
+}
+
+/* Action signal to move focus to last focusable actor was emitted */
+static gboolean _xfdashboard_focus_manager_move_focus_last(XfdashboardFocusManager *self,
+															XfdashboardFocusable *inSource,
+															const gchar *inAction,
+															ClutterEvent *inEvent)
+{
+	XfdashboardFocusManagerPrivate	*priv;
+	XfdashboardFocusable			*currentFocusable;
+	XfdashboardFocusable			*newFocusable;
+	GList							*iter;
+
+	g_return_val_if_fail(XFDASHBOARD_IS_FOCUS_MANAGER(self), CLUTTER_EVENT_PROPAGATE);
+	g_return_val_if_fail(inEvent, CLUTTER_EVENT_PROPAGATE);
+
+	priv=self->priv;
+
+	/* Get current focus */
+	currentFocusable=xfdashboard_focus_manager_get_focus(self);
+
+	/* Iterate backwards through registered focusable actor and find the last focusable
+	 * one. We do not use xfdashboard_focus_manager_get_previous_focusable(self, NULL)
+	 * as it could return a focusable actor which is before the current one in order.
+	 * We do not want to change the focus if it is not "after" the current one.
+	 */
+	for(iter=g_list_last(priv->registeredFocusables); iter; iter=g_list_previous(iter))
+	{
+		newFocusable=(XfdashboardFocusable*)iter->data;
+
+		/* If iterate reached the current focused actor then there it is no last
+		 * focusable actor and we do not need to change the focus and can return.
+		 */
+		if(currentFocusable && newFocusable==currentFocusable) return(CLUTTER_EVENT_STOP);
+
+		/* If focusable can be focused then focus it and return */
+		if(xfdashboard_focusable_can_focus(newFocusable))
+		{
+			xfdashboard_focus_manager_set_focus(self, newFocusable);
+
+			return(CLUTTER_EVENT_STOP);
+		}
+	}
+
+	/* If we get here we iterated through all registered focusable actors but
+	 * could not find a matching one to set focus to.
+	 */
+	return(CLUTTER_EVENT_STOP);
+}
+
 /* Action signal to move focus to next focusable actor was emitted */
 static gboolean _xfdashboard_focus_manager_move_focus_next(XfdashboardFocusManager *self,
 															XfdashboardFocusable *inSource,
@@ -284,6 +384,8 @@ static void xfdashboard_focus_manager_class_init(XfdashboardFocusManagerClass *k
 	/* Override functions */
 	gobjectClass->dispose=_xfdashboard_focus_manager_dispose;
 
+	klass->focus_move_first=_xfdashboard_focus_manager_move_focus_first;
+	klass->focus_move_last=_xfdashboard_focus_manager_move_focus_last;
 	klass->focus_move_next=_xfdashboard_focus_manager_move_focus_next;
 	klass->focus_move_previous=_xfdashboard_focus_manager_move_focus_previous;
 
@@ -328,6 +430,34 @@ static void xfdashboard_focus_manager_class_init(XfdashboardFocusManagerClass *k
 						XFDASHBOARD_TYPE_FOCUSABLE,
 						XFDASHBOARD_TYPE_FOCUSABLE);
 
+	XfdashboardFocusManagerSignals[ACTION_FOCUS_MOVE_FIRST]=
+		g_signal_new("focus-move-first",
+						G_TYPE_FROM_CLASS(klass),
+						G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+						G_STRUCT_OFFSET(XfdashboardFocusManagerClass, focus_move_first),
+						g_signal_accumulator_true_handled,
+						NULL,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
+						G_TYPE_BOOLEAN,
+						3,
+						XFDASHBOARD_TYPE_FOCUSABLE,
+						G_TYPE_STRING,
+						CLUTTER_TYPE_EVENT);
+
+	XfdashboardFocusManagerSignals[ACTION_FOCUS_MOVE_LAST]=
+		g_signal_new("focus-move-last",
+						G_TYPE_FROM_CLASS(klass),
+						G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+						G_STRUCT_OFFSET(XfdashboardFocusManagerClass, focus_move_last),
+						g_signal_accumulator_true_handled,
+						NULL,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
+						G_TYPE_BOOLEAN,
+						3,
+						XFDASHBOARD_TYPE_FOCUSABLE,
+						G_TYPE_STRING,
+						CLUTTER_TYPE_EVENT);
+
 	XfdashboardFocusManagerSignals[ACTION_FOCUS_MOVE_NEXT]=
 		g_signal_new("focus-move-next",
 						G_TYPE_FROM_CLASS(klass),
@@ -335,7 +465,7 @@ static void xfdashboard_focus_manager_class_init(XfdashboardFocusManagerClass *k
 						G_STRUCT_OFFSET(XfdashboardFocusManagerClass, focus_move_next),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -349,7 +479,7 @@ static void xfdashboard_focus_manager_class_init(XfdashboardFocusManagerClass *k
 						G_STRUCT_OFFSET(XfdashboardFocusManagerClass, focus_move_previous),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -425,7 +555,9 @@ void xfdashboard_focus_manager_register_after(XfdashboardFocusManager *self, Xfd
 	{
 		gint						insertPosition;
 
-		g_debug("Registering focusable %s", G_OBJECT_TYPE_NAME(inFocusable));
+		XFDASHBOARD_DEBUG(self, MISC,
+							"Registering focusable %s",
+							G_OBJECT_TYPE_NAME(inFocusable));
 
 		/* If requested find position of focusable actor to insert new focusable actor after.
 		 * Increase found position by one and add new focusable actor to list of registered
@@ -482,7 +614,9 @@ void xfdashboard_focus_manager_unregister(XfdashboardFocusManager *self, Xfdashb
 	 */
 	if(g_list_find(priv->registeredFocusables, inFocusable)!=NULL)
 	{
-		g_debug("Unregistering focusable %s", G_OBJECT_TYPE_NAME(inFocusable));
+		XFDASHBOARD_DEBUG(self, MISC,
+							"Unregistering focusable %s",
+							G_OBJECT_TYPE_NAME(inFocusable));
 
 		/* If we unregister the focusable actor which has the focus currently
 		 * move focus to next focusable actor first but check that we will not
@@ -635,9 +769,10 @@ GSList* xfdashboard_focus_manager_get_targets(XfdashboardFocusManager *self, con
 	}
 
 	/* Return list of targets found */
-	g_debug("Target list for target class '%s' has %d entries",
-				inTarget,
-				g_slist_length(targets));
+	XFDASHBOARD_DEBUG(self, MISC,
+						"Target list for target class '%s' has %d entries",
+						inTarget,
+						g_slist_length(targets));
 
 	return(targets);
 }
@@ -699,14 +834,16 @@ void xfdashboard_focus_manager_set_focus(XfdashboardFocusManager *self, Xfdashbo
 		newFocusable=xfdashboard_focus_manager_get_next_focusable(self, inFocusable);
 		if(!newFocusable)
 		{
-			g_debug("Requested focusable actor '%s' cannot be focus but no other focusable actor was found",
-						G_OBJECT_TYPE_NAME(inFocusable));
+			XFDASHBOARD_DEBUG(self, MISC,
+								"Requested focusable actor '%s' cannot be focus but no other focusable actor was found",
+								G_OBJECT_TYPE_NAME(inFocusable));
 			return;
 		}
 
-		g_debug("Requested focusable actor '%s' cannot be focused - moving focus to '%s'",
-				G_OBJECT_TYPE_NAME(inFocusable),
-				newFocusable ? G_OBJECT_TYPE_NAME(newFocusable) : "<nothing>");
+		XFDASHBOARD_DEBUG(self, MISC,
+							"Requested focusable actor '%s' cannot be focused - moving focus to '%s'",
+							G_OBJECT_TYPE_NAME(inFocusable),
+							newFocusable ? G_OBJECT_TYPE_NAME(newFocusable) : "<nothing>");
 		inFocusable=newFocusable;
 	}
 
@@ -714,7 +851,7 @@ void xfdashboard_focus_manager_set_focus(XfdashboardFocusManager *self, Xfdashbo
 	oldFocusable=priv->currentFocus;
 	if(oldFocusable==inFocusable)
 	{
-		g_debug("Current focused actor and new one are the same so do nothing.");
+		XFDASHBOARD_DEBUG(self, MISC, "Current focused actor and new one are the same so do nothing.");
 		return;
 	}
 
@@ -728,9 +865,10 @@ void xfdashboard_focus_manager_set_focus(XfdashboardFocusManager *self, Xfdashbo
 	/* Set focus to new focusable actor */
 	priv->currentFocus=inFocusable;
 	xfdashboard_focusable_set_focus(priv->currentFocus);
-	g_debug("Moved focus from '%s' to '%s'",
-				oldFocusable ? G_OBJECT_TYPE_NAME(oldFocusable) : "<nothing>",
-				G_OBJECT_TYPE_NAME(priv->currentFocus));
+	XFDASHBOARD_DEBUG(self, MISC,
+						"Moved focus from '%s' to '%s'",
+						oldFocusable ? G_OBJECT_TYPE_NAME(oldFocusable) : "<nothing>",
+						G_OBJECT_TYPE_NAME(priv->currentFocus));
 
 	/* Emit signal for changed focus */
 	g_signal_emit(self, XfdashboardFocusManagerSignals[SIGNAL_CHANGED], 0, oldFocusable, priv->currentFocus);
@@ -993,9 +1131,10 @@ gboolean xfdashboard_focus_manager_handle_key_event(XfdashboardFocusManager *sel
 		eventStatus=CLUTTER_EVENT_PROPAGATE;
 
 		/* Emit action of binding to each actor in target list just build up */
-		g_debug("Target list for action '%s' has %d actors",
-					action,
-					g_slist_length(targetFocusables));
+		XFDASHBOARD_DEBUG(self, MISC,
+							"Target list for action '%s' has %d actors",
+							action,
+							g_slist_length(targetFocusables));
 
 		for(iter=targetFocusables; iter; iter=g_slist_next(iter))
 		{
@@ -1075,14 +1214,16 @@ gboolean xfdashboard_focus_manager_handle_key_event(XfdashboardFocusManager *sel
 #endif
 
 			/* Emit action signal at target */
-			g_debug("Emitting action signal '%s' at focusable actor %s",
-						action,
-						G_OBJECT_TYPE_NAME(targetObject));
+			XFDASHBOARD_DEBUG(self, ACTOR,
+								"Emitting action signal '%s' at focusable actor %s",
+								action,
+								G_OBJECT_TYPE_NAME(targetObject));
 			g_signal_emit_by_name(targetObject, action, inFocusable, action, inEvent, &eventStatus);
-			g_debug("Action signal '%s' was %s by focusable actor %s",
-						action,
-						eventStatus==CLUTTER_EVENT_STOP ? "handled" : "not handled",
-						G_OBJECT_TYPE_NAME(targetObject));
+			XFDASHBOARD_DEBUG(self, ACTOR,
+								"Action signal '%s' was %s by focusable actor %s",
+								action,
+								eventStatus==CLUTTER_EVENT_STOP ? "handled" : "not handled",
+								G_OBJECT_TYPE_NAME(targetObject));
 		}
 
 		/* Release allocated resources */
