@@ -35,9 +35,12 @@
 #include <libxfdashboard/live-window-simple.h>
 #include <libxfdashboard/window-tracker.h>
 #include <libxfdashboard/click-action.h>
+#include <libxfdashboard/drag-action.h>
+#include <libxfdashboard/image-content.h>
 #include <libxfdashboard/enums.h>
 #include <libxfdashboard/stylable.h>
 #include <libxfdashboard/compat.h>
+#include <libxfdashboard/debug.h>
 
 
 /* Define this class in GObject system */
@@ -62,6 +65,7 @@ struct _XfdashboardLiveWorkspacePrivate
 	XfdashboardWindowTracker				*windowTracker;
 	ClutterActor							*backgroundImageLayer;
 	ClutterActor							*actorTitle;
+	ClutterAction							*clickAction;
 };
 
 /* Properties */
@@ -91,23 +95,26 @@ enum
 static guint XfdashboardLiveWorkspaceSignals[SIGNAL_LAST]={ 0, };
 
 /* IMPLEMENTATION: Private variables and methods */
+#define DEFAULT_DRAG_HANDLE_SIZE						32.0f
 
 /* Check if window should be shown */
 static gboolean _xfdashboard_live_workspace_is_visible_window(XfdashboardLiveWorkspace *self,
 																XfdashboardWindowTrackerWindow *inWindow)
 {
-	XfdashboardLiveWorkspacePrivate		*priv;
+	XfdashboardLiveWorkspacePrivate			*priv;
+	XfdashboardWindowTrackerWindowState		state;
 
 	g_return_val_if_fail(XFDASHBOARD_IS_LIVE_WORKSPACE(self), FALSE);
 	g_return_val_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER_WINDOW(inWindow), FALSE);
 
 	priv=self->priv;
 
-	/* Determine if windows should be shown depending on its state */
-	if(xfdashboard_window_tracker_window_is_skip_pager(inWindow) ||
-		xfdashboard_window_tracker_window_is_skip_tasklist(inWindow) ||
+	/* Determine if windows should be shown at workspace depending on its state */
+	state=xfdashboard_window_tracker_window_get_state(inWindow);
+	if((state & XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_SKIP_PAGER) ||
+		(state & XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_SKIP_TASKLIST) ||
 		!xfdashboard_window_tracker_window_is_visible(inWindow) ||
-		(!priv->workspace && !xfdashboard_window_tracker_window_is_pinned(inWindow)) ||
+		(!priv->workspace && !(state & XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_PINNED)) ||
 		(priv->workspace && !xfdashboard_window_tracker_window_is_on_workspace(inWindow, priv->workspace)) ||
 		xfdashboard_window_tracker_window_is_stage(inWindow))
 	{
@@ -146,6 +153,88 @@ static ClutterActor* _xfdashboard_live_workspace_find_by_window(XfdashboardLiveW
 	return(NULL);
 }
 
+/* Drag of a live window begins */
+static void _xfdashboard_live_workspace_on_window_drag_begin(ClutterDragAction *inAction,
+																ClutterActor *inActor,
+																gfloat inStageX,
+																gfloat inStageY,
+																ClutterModifierType inModifiers,
+																gpointer inUserData)
+{
+	XfdashboardLiveWorkspace			*self;
+	XfdashboardLiveWorkspacePrivate		*priv;
+	ClutterActor						*dragHandle;
+	ClutterStage						*stage;
+	GdkPixbuf							*windowIcon;
+	ClutterContent						*image;
+	XfdashboardLiveWindowSimple			*liveWindow;
+
+	g_return_if_fail(CLUTTER_IS_DRAG_ACTION(inAction));
+	g_return_if_fail(XFDASHBOARD_IS_LIVE_WINDOW_SIMPLE(inActor));
+	g_return_if_fail(XFDASHBOARD_IS_LIVE_WORKSPACE(inUserData));
+
+	self=XFDASHBOARD_LIVE_WORKSPACE(inUserData);
+	priv=self->priv;
+	liveWindow=XFDASHBOARD_LIVE_WINDOW_SIMPLE(inActor);
+
+	/* Prevent signal "clicked" from being emitted on live workspace actor */
+	clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(priv->clickAction), FALSE);
+
+	/* Get stage */
+	stage=CLUTTER_STAGE(clutter_actor_get_stage(inActor));
+
+	/* Create a application icon for drag handle */
+	windowIcon=xfdashboard_window_tracker_window_get_icon(xfdashboard_live_window_simple_get_window(liveWindow));
+	image=xfdashboard_image_content_new_for_pixbuf(windowIcon);
+
+	dragHandle=xfdashboard_background_new();
+	clutter_actor_set_position(dragHandle, inStageX, inStageY);
+	clutter_actor_set_size(dragHandle, DEFAULT_DRAG_HANDLE_SIZE, DEFAULT_DRAG_HANDLE_SIZE);
+	xfdashboard_background_set_image(XFDASHBOARD_BACKGROUND(dragHandle), CLUTTER_IMAGE(image));
+	clutter_actor_add_child(CLUTTER_ACTOR(stage), dragHandle);
+
+	clutter_drag_action_set_drag_handle(inAction, dragHandle);
+
+	g_object_unref(image);
+}
+
+/* Drag of a live window ends */
+static void _xfdashboard_live_workspace_on_window_on_drag_end(ClutterDragAction *inAction,
+																ClutterActor *inActor,
+																gfloat inStageX,
+																gfloat inStageY,
+																ClutterModifierType inModifiers,
+																gpointer inUserData)
+{
+	XfdashboardLiveWorkspace			*self;
+	XfdashboardLiveWorkspacePrivate		*priv;
+	ClutterActor						*dragHandle;
+
+	g_return_if_fail(CLUTTER_IS_DRAG_ACTION(inAction));
+	g_return_if_fail(XFDASHBOARD_IS_LIVE_WINDOW_SIMPLE(inActor));
+	g_return_if_fail(XFDASHBOARD_IS_LIVE_WORKSPACE(inUserData));
+
+	self=XFDASHBOARD_LIVE_WORKSPACE(inUserData);
+	priv=self->priv;
+
+	/* Destroy clone of application icon used as drag handle */
+	dragHandle=clutter_drag_action_get_drag_handle(inAction);
+	if(dragHandle)
+	{
+#if CLUTTER_CHECK_VERSION(1, 14, 0)
+		/* Only unset drag handle if not running Clutter in version
+		 * 1.12. This prevents a critical warning message in 1.12.
+		 * Later versions of Clutter are fixed already.
+		 */
+		clutter_drag_action_set_drag_handle(inAction, NULL);
+#endif
+		clutter_actor_destroy(dragHandle);
+	}
+
+	/* Allow signal "clicked" from being emitted again */
+	clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(priv->clickAction), TRUE);
+}
+
 /* Create actor for window but respect window stacking when adding */
 static ClutterActor* _xfdashboard_live_workspace_create_and_add_window_actor(XfdashboardLiveWorkspace *self,
 																				XfdashboardWindowTrackerWindow *inWindow)
@@ -155,6 +244,7 @@ static ClutterActor* _xfdashboard_live_workspace_create_and_add_window_actor(Xfd
 	GList								*windows;
 	ClutterActor						*lastWindowActor;
 	XfdashboardWindowTrackerWindow		*window;
+	ClutterAction						*action;
 
 	g_return_val_if_fail(XFDASHBOARD_IS_LIVE_WORKSPACE(self), NULL);
 	g_return_val_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER_WINDOW(inWindow), NULL);
@@ -163,12 +253,12 @@ static ClutterActor* _xfdashboard_live_workspace_create_and_add_window_actor(Xfd
 
 	/* We cannot assume that each window newly opened or moved to this workspace
 	 * will be on top of all other windows. We need to respect window stacking.
-	 * Therefore we iterate through list of windows in stacking order and find
-	 * the last window we have an actor for before we the window requested.
+	 * Therefore we iterate through list of windows in reversed stacking order
+	 * and find the last window we have an actor for before we the window requested.
 	 */
 	lastWindowActor=NULL;
 	windows=xfdashboard_window_tracker_get_windows_stacked(priv->windowTracker);
-	for( ; windows; windows=g_list_next(windows))
+	for(windows=g_list_last(windows) ; windows; windows=g_list_previous(windows))
 	{
 		/* Get window from list */
 		window=XFDASHBOARD_WINDOW_TRACKER_WINDOW(windows->data);
@@ -190,18 +280,56 @@ static ClutterActor* _xfdashboard_live_workspace_create_and_add_window_actor(Xfd
 		/* Move existing window actor to new stacking position */
 		g_object_ref(actor);
 		clutter_actor_remove_child(CLUTTER_ACTOR(self), actor);
-		if(lastWindowActor) clutter_actor_insert_child_above(CLUTTER_ACTOR(self), actor, lastWindowActor);
-			else clutter_actor_insert_child_below(CLUTTER_ACTOR(self), actor, priv->actorTitle);
+		if(lastWindowActor)
+		{
+			clutter_actor_insert_child_above(CLUTTER_ACTOR(self), actor, lastWindowActor);
+			XFDASHBOARD_DEBUG(self, ACTOR,
+								"Moved existing actor for window '%s' above actor for window '%s' at live workspace '%s'",
+								xfdashboard_window_tracker_window_get_name(xfdashboard_live_window_simple_get_window(XFDASHBOARD_LIVE_WINDOW_SIMPLE(actor))),
+								xfdashboard_window_tracker_window_get_name(xfdashboard_live_window_simple_get_window(XFDASHBOARD_LIVE_WINDOW_SIMPLE(lastWindowActor))),
+								xfdashboard_window_tracker_workspace_get_name(priv->workspace));
+		}
+			else
+			{
+				clutter_actor_insert_child_below(CLUTTER_ACTOR(self), actor, priv->actorTitle);
+				XFDASHBOARD_DEBUG(self, ACTOR,
+									"Moved existing actor for window '%s' to bottom at live workspace '%s'",
+									xfdashboard_window_tracker_window_get_name(xfdashboard_live_window_simple_get_window(XFDASHBOARD_LIVE_WINDOW_SIMPLE(actor))),
+									xfdashboard_window_tracker_workspace_get_name(priv->workspace));
+			}
 		g_object_unref(actor);
+
 	}
 		else
 		{
 			/* Create actor */
 			actor=xfdashboard_live_window_simple_new_for_window(inWindow);
 
+			/* Add drag action to actor */
+			action=xfdashboard_drag_action_new_with_source(CLUTTER_ACTOR(self));
+			clutter_drag_action_set_drag_threshold(CLUTTER_DRAG_ACTION(action), -1, -1);
+			clutter_actor_add_action(actor, action);
+			g_signal_connect(action, "drag-begin", G_CALLBACK(_xfdashboard_live_workspace_on_window_drag_begin), self);
+			g_signal_connect(action, "drag-end", G_CALLBACK(_xfdashboard_live_workspace_on_window_on_drag_end), self);
+
 			/* Add new actor at right stacking position */
-			if(lastWindowActor) clutter_actor_insert_child_above(CLUTTER_ACTOR(self), actor, lastWindowActor);
-				else clutter_actor_insert_child_below(CLUTTER_ACTOR(self), actor, priv->actorTitle);
+			if(lastWindowActor)
+			{
+				clutter_actor_insert_child_above(CLUTTER_ACTOR(self), actor, lastWindowActor);
+				XFDASHBOARD_DEBUG(self, ACTOR,
+									"Created new actor for window '%s' above actor for window '%s' at live workspace '%s'",
+									xfdashboard_window_tracker_window_get_name(xfdashboard_live_window_simple_get_window(XFDASHBOARD_LIVE_WINDOW_SIMPLE(actor))),
+									xfdashboard_window_tracker_window_get_name(xfdashboard_live_window_simple_get_window(XFDASHBOARD_LIVE_WINDOW_SIMPLE(lastWindowActor))),
+									xfdashboard_window_tracker_workspace_get_name(priv->workspace));
+			}
+				else
+				{
+					clutter_actor_insert_child_below(CLUTTER_ACTOR(self), actor, priv->actorTitle);
+					XFDASHBOARD_DEBUG(self, ACTOR,
+										"Created new actor for window '%s' to bottom at live workspace '%s'",
+										xfdashboard_window_tracker_window_get_name(xfdashboard_live_window_simple_get_window(XFDASHBOARD_LIVE_WINDOW_SIMPLE(actor))),
+										xfdashboard_window_tracker_workspace_get_name(priv->workspace));
+				}
 		}
 
 	return(actor);
@@ -427,8 +555,9 @@ static void _xfdashboard_live_workspace_on_desktop_window_opened(XfdashboardLive
 		g_signal_handlers_disconnect_by_func(priv->windowTracker,
 												G_CALLBACK(_xfdashboard_live_workspace_on_desktop_window_opened),
 												self);
-		g_debug("Found desktop window for workspace '%s' with signal 'window-opened', so disconnecting signal handler",
-				xfdashboard_window_tracker_workspace_get_name(priv->workspace));
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"Found desktop window for workspace '%s' with signal 'window-opened', so disconnecting signal handler",
+							xfdashboard_window_tracker_workspace_get_name(priv->workspace));
 	}
 }
 
@@ -443,6 +572,7 @@ static void _xfdashboard_live_workspace_get_preferred_height(ClutterActor *self,
 	XfdashboardLiveWorkspacePrivate		*priv=XFDASHBOARD_LIVE_WORKSPACE(self)->priv;
 	gfloat								minHeight, naturalHeight;
 	gfloat								childWidth, childHeight;
+	gint								w, h;
 
 	minHeight=naturalHeight=0.0f;
 
@@ -451,13 +581,15 @@ static void _xfdashboard_live_workspace_get_preferred_height(ClutterActor *self,
 	{
 		if(priv->monitor)
 		{
-			childWidth=(gfloat)xfdashboard_window_tracker_monitor_get_width(priv->monitor);
-			childHeight=(gfloat)xfdashboard_window_tracker_monitor_get_height(priv->monitor);
+			xfdashboard_window_tracker_monitor_get_geometry(priv->monitor, NULL, NULL, &w, &h);
+			childWidth=(gfloat)w;
+			childHeight=(gfloat)h;
 		}
 			else
 			{
-				childWidth=(gfloat)xfdashboard_window_tracker_workspace_get_width(priv->workspace);
-				childHeight=(gfloat)xfdashboard_window_tracker_workspace_get_height(priv->workspace);
+				xfdashboard_window_tracker_workspace_get_size(priv->workspace, &w, &h);
+				childWidth=(gfloat)w;
+				childHeight=(gfloat)h;
 			}
 
 		if(inForWidth<0.0f) naturalHeight=childHeight;
@@ -477,6 +609,7 @@ static void _xfdashboard_live_workspace_get_preferred_width(ClutterActor *self,
 	XfdashboardLiveWorkspacePrivate		*priv=XFDASHBOARD_LIVE_WORKSPACE(self)->priv;
 	gfloat								minWidth, naturalWidth;
 	gfloat								childWidth, childHeight;
+	gint								w, h;
 
 	minWidth=naturalWidth=0.0f;
 
@@ -485,13 +618,15 @@ static void _xfdashboard_live_workspace_get_preferred_width(ClutterActor *self,
 	{
 		if(priv->monitor)
 		{
-			childWidth=(gfloat)xfdashboard_window_tracker_monitor_get_width(priv->monitor);
-			childHeight=(gfloat)xfdashboard_window_tracker_monitor_get_height(priv->monitor);
+			xfdashboard_window_tracker_monitor_get_geometry(priv->monitor, NULL, NULL, &w, &h);
+			childWidth=(gfloat)w;
+			childHeight=(gfloat)h;
 		}
 			else
 			{
-				childWidth=(gfloat)xfdashboard_window_tracker_workspace_get_width(priv->workspace);
-				childHeight=(gfloat)xfdashboard_window_tracker_workspace_get_height(priv->workspace);
+				xfdashboard_window_tracker_workspace_get_size(priv->workspace, &w, &h);
+				childWidth=(gfloat)w;
+				childHeight=(gfloat)h;
 			}
 
 		if(inForHeight<0.0f) naturalWidth=childWidth;
@@ -559,17 +694,19 @@ static void _xfdashboard_live_workspace_allocate(ClutterActor *self,
 	 */
 	if(priv->workspace)
 	{
+		xfdashboard_window_tracker_workspace_get_size(priv->workspace, &w, &h);
 		workspaceArea.x1=0.0f;
 		workspaceArea.y1=0.0f;
-		workspaceArea.x2=xfdashboard_window_tracker_workspace_get_width(priv->workspace);
-		workspaceArea.y2=xfdashboard_window_tracker_workspace_get_height(priv->workspace);
+		workspaceArea.x2=w;
+		workspaceArea.y2=h;
 	}
 		else
 		{
+			xfdashboard_window_tracker_get_screen_size(priv->windowTracker, &w, &h);
 			workspaceArea.x1=0.0f;
 			workspaceArea.y1=0.0f;
-			workspaceArea.x2=xfdashboard_window_tracker_get_screen_width(priv->windowTracker);
-			workspaceArea.y2=xfdashboard_window_tracker_get_screen_height(priv->windowTracker);
+			workspaceArea.x2=w;
+			workspaceArea.y2=h;
 		}
 
 	/* Get visible area of workspace */
@@ -644,7 +781,7 @@ static void _xfdashboard_live_workspace_allocate(ClutterActor *self,
 		if(!window || !XFDASHBOARD_IS_WINDOW_TRACKER_WINDOW(window)) continue;
 
 		/* Get real size of child */
-		xfdashboard_window_tracker_window_get_position_size(window, &x, &y, &w, &h);
+		xfdashboard_window_tracker_window_get_geometry(window, &x, &y, &w, &h);
 
 		/* Calculate translated position and size of child */
 		childAllocation.x1=x-visibleArea.x1;
@@ -712,6 +849,12 @@ static void _xfdashboard_live_workspace_dispose(GObject *inObject)
 		priv->workspace=NULL;
 	}
 
+	if(priv->clickAction)
+	{
+		clutter_actor_remove_action(CLUTTER_ACTOR(self), priv->clickAction);
+		priv->clickAction=NULL;
+	}
+
 	/* Call parent's class dispose method */
 	G_OBJECT_CLASS(xfdashboard_live_workspace_parent_class)->dispose(inObject);
 }
@@ -873,7 +1016,6 @@ static void xfdashboard_live_workspace_class_init(XfdashboardLiveWorkspaceClass
 static void xfdashboard_live_workspace_init(XfdashboardLiveWorkspace *self)
 {
 	XfdashboardLiveWorkspacePrivate		*priv;
-	ClutterAction						*action;
 
 	priv=self->priv=XFDASHBOARD_LIVE_WORKSPACE_GET_PRIVATE(self);
 
@@ -889,9 +1031,9 @@ static void xfdashboard_live_workspace_init(XfdashboardLiveWorkspace *self)
 	clutter_actor_set_reactive(CLUTTER_ACTOR(self), TRUE);
 
 	/* Connect signals */
-	action=xfdashboard_click_action_new();
-	clutter_actor_add_action(CLUTTER_ACTOR(self), action);
-	g_signal_connect_swapped(action, "clicked", G_CALLBACK(_xfdashboard_live_workspace_on_clicked), self);
+	priv->clickAction=xfdashboard_click_action_new();
+	clutter_actor_add_action(CLUTTER_ACTOR(self), priv->clickAction);
+	g_signal_connect_swapped(priv->clickAction, "clicked", G_CALLBACK(_xfdashboard_live_workspace_on_clicked), self);
 
 	/* Create background actors but order of adding background children is important */
 	priv->backgroundImageLayer=xfdashboard_live_window_simple_new();
@@ -1106,8 +1248,9 @@ void xfdashboard_live_workspace_set_background_image_type(XfdashboardLiveWorkspa
 						if(backgroundWindow)
 						{
 							xfdashboard_live_window_simple_set_window(XFDASHBOARD_LIVE_WINDOW_SIMPLE(priv->backgroundImageLayer), backgroundWindow);
-							g_debug("Desktop window was found and set up as background image for workspace '%s'",
-									xfdashboard_window_tracker_workspace_get_name(priv->workspace));
+							XFDASHBOARD_DEBUG(self, ACTOR,
+												"Desktop window was found and set up as background image for workspace '%s'",
+												xfdashboard_window_tracker_workspace_get_name(priv->workspace));
 						}
 							else
 							{
@@ -1115,8 +1258,9 @@ void xfdashboard_live_workspace_set_background_image_type(XfdashboardLiveWorkspa
 															"window-opened",
 															G_CALLBACK(_xfdashboard_live_workspace_on_desktop_window_opened),
 															self);
-								g_debug("Desktop window was not found. Setting up signal to get notified when desktop window might be opened for workspace '%s'",
-											xfdashboard_window_tracker_workspace_get_name(priv->workspace));
+								XFDASHBOARD_DEBUG(self, ACTOR,
+													"Desktop window was not found. Setting up signal to get notified when desktop window might be opened for workspace '%s'",
+													xfdashboard_window_tracker_workspace_get_name(priv->workspace));
 							}
 					}
 					break;
