@@ -50,7 +50,44 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:FLOAT,FLOAT (marshal.list:1) */
+/* VOID:FLAGS,FLAGS (marshal.list:1) */
+void
+_xfdashboard_marshal_VOID__FLAGS_FLAGS (GClosure     *closure,
+                                        GValue       *return_value G_GNUC_UNUSED,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint G_GNUC_UNUSED,
+                                        gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__FLAGS_FLAGS) (gpointer     data1,
+                                                  guint        arg_1,
+                                                  guint        arg_2,
+                                                  gpointer     data2);
+  GMarshalFunc_VOID__FLAGS_FLAGS callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__FLAGS_FLAGS) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_flags (param_values + 1),
+            g_marshal_value_peek_flags (param_values + 2),
+            data2);
+}
+
+/* VOID:FLOAT,FLOAT (marshal.list:2) */
 void
 _xfdashboard_marshal_VOID__FLOAT_FLOAT (GClosure     *closure,
                                         GValue       *return_value G_GNUC_UNUSED,
@@ -87,7 +124,7 @@ _xfdashboard_marshal_VOID__FLOAT_FLOAT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT (marshal.list:2) */
+/* VOID:INT,INT (marshal.list:3) */
 void
 _xfdashboard_marshal_VOID__INT_INT (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -124,47 +161,6 @@ _xfdashboard_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT,INT,INT (marshal.list:3) */
-void
-_xfdashboard_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
-                                            GValue       *return_value G_GNUC_UNUSED,
-                                            guint         n_param_values,
-                                            const GValue *param_values,
-                                            gpointer      invocation_hint G_GNUC_UNUSED,
-                                            gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__INT_INT_INT_INT) (gpointer     data1,
-                                                      gint         arg_1,
-                                                      gint         arg_2,
-                                                      gint         arg_3,
-                                                      gint         arg_4,
-                                                      gpointer     data2);
-  GMarshalFunc_VOID__INT_INT_INT_INT callback;
-  GCClosure *cc = (GCClosure*) closure;
-  gpointer data1, data2;
-
-  g_return_if_fail (n_param_values == 5);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__INT_INT_INT_INT) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_marshal_value_peek_int (param_values + 1),
-            g_marshal_value_peek_int (param_values + 2),
-            g_marshal_value_peek_int (param_values + 3),
-            g_marshal_value_peek_int (param_values + 4),
-            data2);
-}
-
 /* VOID:OBJECT,OBJECT (marshal.list:4) */
 void
 _xfdashboard_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
@@ -440,21 +436,21 @@ _xfdashboard_marshal_BOOLEAN__OBJECT_FLOAT_FLOAT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING,OBJECT (marshal.list:11) */
+/* BOOLEAN:OBJECT,STRING,BOXED (marshal.list:11) */
 void
-_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT (GClosure     *closure,
-                                                    GValue       *return_value G_GNUC_UNUSED,
-                                                    guint         n_param_values,
-                                                    const GValue *param_values,
-                                                    gpointer      invocation_hint G_GNUC_UNUSED,
-                                                    gpointer      marshal_data)
+_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED (GClosure     *closure,
+                                                   GValue       *return_value G_GNUC_UNUSED,
+                                                   guint         n_param_values,
+                                                   const GValue *param_values,
+                                                   gpointer      invocation_hint G_GNUC_UNUSED,
+                                                   gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT_STRING_OBJECT) (gpointer     data1,
-                                                                  gpointer     arg_1,
-                                                                  gpointer     arg_2,
-                                                                  gpointer     arg_3,
-                                                                  gpointer     data2);
-  GMarshalFunc_BOOLEAN__OBJECT_STRING_OBJECT callback;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT_STRING_BOXED) (gpointer     data1,
+                                                                 gpointer     arg_1,
+                                                                 gpointer     arg_2,
+                                                                 gpointer     arg_3,
+                                                                 gpointer     data2);
+  GMarshalFunc_BOOLEAN__OBJECT_STRING_BOXED callback;
   GCClosure *cc = (GCClosure*) closure;
   gpointer data1, data2;
   gboolean v_return;
@@ -472,55 +468,18 @@ _xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_BOOLEAN__OBJECT_STRING_OBJECT) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_BOOLEAN__OBJECT_STRING_BOXED) (marshal_data ? marshal_data : cc->callback);
 
   v_return = callback (data1,
                        g_marshal_value_peek_object (param_values + 1),
                        g_marshal_value_peek_string (param_values + 2),
-                       g_marshal_value_peek_object (param_values + 3),
+                       g_marshal_value_peek_boxed (param_values + 3),
                        data2);
 
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (marshal.list:12) */
-void
-_xfdashboard_marshal_BOOLEAN__VOID (GClosure     *closure,
-                                    GValue       *return_value G_GNUC_UNUSED,
-                                    guint         n_param_values,
-                                    const GValue *param_values,
-                                    gpointer      invocation_hint G_GNUC_UNUSED,
-                                    gpointer      marshal_data)
-{
-  typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
-                                                  gpointer     data2);
-  GMarshalFunc_BOOLEAN__VOID callback;
-  GCClosure *cc = (GCClosure*) closure;
-  gpointer data1, data2;
-  gboolean v_return;
-
-  g_return_if_fail (return_value != NULL);
-  g_return_if_fail (n_param_values == 1);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_BOOLEAN__VOID) (marshal_data ? marshal_data : cc->callback);
-
-  v_return = callback (data1,
-                       data2);
-
-  g_value_set_boolean (return_value, v_return);
-}
-
-/* OBJECT:VOID (marshal.list:13) */
+/* OBJECT:VOID (marshal.list:12) */
 void
 _xfdashboard_marshal_OBJECT__VOID (GClosure     *closure,
                                    GValue       *return_value G_GNUC_UNUSED,
