@@ -31,9 +31,10 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <libxfdashboard/x11/window-tracker-x11.h>
+#include <libxfdashboard/window-tracker-backend.h>
 #include <libxfdashboard/marshal.h>
 #include <libxfdashboard/compat.h>
+#include <libxfdashboard/debug.h>
 
 
 /* Define this class in GObject system */
@@ -83,8 +84,6 @@ static guint XfdashboardWindowTrackerSignals[SIGNAL_LAST]={ 0, };
 				G_OBJECT_TYPE_NAME(self), \
 				vfunc);
 
-static XfdashboardWindowTracker *_xfdashboard_window_tracker_singleton=NULL;
-
 
 /* IMPLEMENTATION: GObject */
 
@@ -572,19 +571,40 @@ void xfdashboard_window_tracker_default_init(XfdashboardWindowTrackerInterface *
  * Retrieves the singleton instance of #XfdashboardWindowTracker. If not needed
  * anymore the caller must unreference the returned object instance.
  *
+ * This function is the logical equivalent of:
+ *
+ * |[<!-- language="C" -->
+ *   XfdashboardWindowTrackerBackend *backend;
+ *   XfdashboardWindowTracker        *tracker;
+ *
+ *   backend=xfdashboard_window_tracker_backend_get_default();
+ *   tracker=xfdashboard_window_tracker_backend_get_window_tracker(backend);
+ *   g_object_unref(backend);
+ * ]|
+ *
  * Return value: (transfer full): The instance of #XfdashboardWindowTracker.
  */
 XfdashboardWindowTracker* xfdashboard_window_tracker_get_default(void)
 {
-	if(G_UNLIKELY(_xfdashboard_window_tracker_singleton==NULL))
+	XfdashboardWindowTrackerBackend		*backend;
+	XfdashboardWindowTracker			*windowTracker;
+
+	/* Get default window tracker backend */
+	backend=xfdashboard_window_tracker_backend_get_default();
+	if(!backend)
 	{
-		_xfdashboard_window_tracker_singleton=
-			XFDASHBOARD_WINDOW_TRACKER(g_object_new(XFDASHBOARD_TYPE_WINDOW_TRACKER_X11, NULL));
+		g_critical(_("Could not get default window tracker backend"));
+		return(NULL);
 	}
-		else g_object_ref(_xfdashboard_window_tracker_singleton);
 
-	return(_xfdashboard_window_tracker_singleton);
+	/* Get window tracker object instance of backend */
+	windowTracker=xfdashboard_window_tracker_backend_get_window_tracker(backend);
 
+	/* Release allocated resources */
+	if(backend) g_object_unref(backend);
+
+	/* Return window tracker object instance */
+	return(windowTracker);
 }
 
 /**
@@ -1088,6 +1108,17 @@ XfdashboardWindowTrackerWindow* xfdashboard_window_tracker_get_root_window(Xfdas
  *
  * Retrieves the window created for the requested stage @inStage.
  *
+ * This function is the logical equivalent of:
+ *
+ * |[<!-- language="C" -->
+ *   XfdashboardWindowTrackerBackend *backend;
+ *   XfdashboardWindowTrackerWindow  *stageWindow;
+ *
+ *   backend=xfdashboard_window_tracker_backend_get_default();
+ *   stageWindow=xfdashboard_window_tracker_backend_get_window_for_stage(backend, inStage);
+ *   g_object_unref(backend);
+ * ]|
+ *
  * Return value: (transfer none): The #XfdashboardWindowTrackerWindow representing
  *   the window of requested stage or %NULL if not available. The returned object
  *   is owned by Xfdashboard and it should not be referenced or unreferenced.
@@ -1095,20 +1126,23 @@ XfdashboardWindowTrackerWindow* xfdashboard_window_tracker_get_root_window(Xfdas
 XfdashboardWindowTrackerWindow* xfdashboard_window_tracker_get_stage_window(XfdashboardWindowTracker *self,
 																			ClutterStage *inStage)
 {
-	XfdashboardWindowTrackerInterface		*iface;
+	XfdashboardWindowTrackerBackend		*backend;
+	XfdashboardWindowTrackerWindow		*stageWindow;
 
-	g_return_val_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER(self), NULL);
-	g_return_val_if_fail(CLUTTER_IS_STAGE(inStage), NULL);
-
-	iface=XFDASHBOARD_WINDOW_TRACKER_GET_IFACE(self);
-
-	/* Call virtual function */
-	if(iface->get_stage_window)
+	/* Get default window tracker backend */
+	backend=xfdashboard_window_tracker_backend_get_default();
+	if(!backend)
 	{
-		return(iface->get_stage_window(self, inStage));
+		g_critical(_("Could not get default window tracker backend"));
+		return(NULL);
 	}
 
-	/* If we get here the virtual function was not overridden */
-	XFDASHBOARD_WINDOWS_TRACKER_WARN_NOT_IMPLEMENTED(self, "get_stage_window");
-	return(NULL);
+	/* Get window for requested stage from backend */
+	stageWindow=xfdashboard_window_tracker_backend_get_window_for_stage(backend, inStage);
+
+	/* Release allocated resources */
+	if(backend) g_object_unref(backend);
+
+	/* Return window object instance */
+	return(stageWindow);
 }
